==> haskell-connection-0.3.1-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-C12bY4xfmmQ2lLqBR677VO
key:                  connection-0.3.1-C12bY4xfmmQ2lLqBR677VO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  211ae798cbb2a1a723d756d4cdc9fc35
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.0.1/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-C12bY4xfmmQ2lLqBR677VO
depends:
    base-4.15.0.0 basement-0.0.12-F0MrM1QYXPfKTXgGX2bdqG
    bytestring-0.10.12.1 containers-0.6.4.1
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    network-3.1.2.2-9BU8QqWnKeP98A8KvbSili
    socks-0.6.1-Db5Gsf1H1XhA3THEjrzTO9 tls-1.5.5-BuJvr5NicsEGoNNqYBzvLY
    x509-1.7.5-KZBg6E9cDNpzkDdONM3tO
    x509-store-1.6.7-GjMuzyM4405JwkexKUzc5E
    x509-system-1.6.6-Fp4NL18jBDD6uZdxyAFfwd
    x509-validation-1.6.11-JdNmOlbiClEBv2zcl7JsJ4

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.3.1-152-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 connection
version:              0.3.1
visibility:           public
id:                   connection-0.3.1-H4KhtDdubpW9iyDC57W5cr
key:                  connection-0.3.1-H4KhtDdubpW9iyDC57W5cr
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-connection
synopsis:             Simple and easy network connections API
description:
    Simple network library for all your connection need.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  5eb5a63a0cb88ef67f92c7f639a7d615
exposed:              True
exposed-modules:      Network.Connection
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.0.1/site-local/connection-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/connection-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/connection-0.3.1
hs-libraries:         HSconnection-0.3.1-H4KhtDdubpW9iyDC57W5cr
depends:
    base-4.15.0.0 basement-0.0.12-F0MrM1QYXPfKTXgGX2bdqG
    bytestring-0.10.12.1 containers-0.6.4.1
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    network-3.1.2.2-HXcjy5szECnDN1PS9jNchP
    socks-0.6.1-DgcGP5kWsheBWznvJKc691 tls-1.5.5-ImjvcimaSLBICjzlYssxAN
    x509-1.7.5-HyBJj96t9GC2vaOmQQ4ozv
    x509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3
    x509-system-1.6.6-9IGmtFMLqYr65UwYvJv3DD
    x509-validation-1.6.11-KMnTpvfp4wJpuZ3bqqSfN

haddock-interfaces:   /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html:         /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
